JSON Schema Sphinx Extension Example
=====================================

This is an example documentation that demonstrates the JSON Schema Sphinx extension.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
   manual_schemas

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
